@@ -15,7 +15,7 @@
 // | Author: Bertrand Mansion <bmansion@mamasam.com>                     |
 // +---------------------------------------------------------------------+
 //
-// $Id: Container.php,v 1.35 2004/10/19 00:57:58 ryansking Exp $
+// $Id: Container.php,v 1.41 2006/05/30 06:37:28 aashley Exp $
 
 require_once 'Config.php';
 
@@ -89,7 +89,11 @@ class Config_Container {
         $this->content    = $content;
         $this->attributes = $attributes;
         $this->parent     = null;
-        $this->_id        = uniqid($name.$type, true);
+        if (version_compare(PHP_VERSION, '5.0.0', 'gt')) {
+            $this->_id    = uniqid($name.$type, true);
+        } else {
+            $this->_id    = uniqid(substr($name.$type, 0, 114), true);
+        }
     } // end constructor
 
     /**
@@ -286,13 +290,15 @@ class Config_Container {
             if (isset($itemsArr[$index])) {
                 return $itemsArr[$index];
             } else {
-                return false;
+                $return = false;
+                return $return;
             }
         } else {
             if ($count = count($itemsArr)) {
                 return $itemsArr[$count-1];
             } else {
-                return false;
+                $return = false;
+                return $return;
             }
         }
     } // end func &getItem
@@ -333,7 +339,8 @@ class Config_Container {
         $match =& $this->getItem(null, $name, null, $attributes);
 
         if (!$match) {
-            return false;
+            $return = false;
+            return $return;
         }
         if (!empty($args)) {
             return $match->searchPath($args);
@@ -401,7 +408,7 @@ class Config_Container {
         $count = 0;
         if (isset($name) && isset($type)) {
             for ($i = 0, $children = count($this->children); $i < $children; $i++) {
-                if ($this->children[$i]->name == $name && 
+                if ($this->children[$i]->name === $name && 
                     $this->children[$i]->type == $type) {
                     $count++;
                 }
@@ -419,7 +426,7 @@ class Config_Container {
         if (isset($name)) {
             // Some directives can have the same name
             for ($i = 0, $children = count($this->children); $i < $children; $i++) {
-                if ($this->children[$i]->name == $name) {
+                if ($this->children[$i]->name === $name) {
                     $count++;
                 }
             }
@@ -466,16 +473,22 @@ class Config_Container {
     /**
     * Returns the item rank in its parent children array
     * according to other items with same type and name.
+    * @param bool  count items differently by type
     * @return int  returns int or null if root object
     */
-    function getItemPosition()
+    function getItemPosition($byType = true)
     {
         if (is_object($this->parent)) {
             $pchildren =& $this->parent->children;
             for ($i = 0, $count = count($pchildren); $i < $count; $i++) {
-                if ($pchildren[$i]->name == $this->name &&
-                    $pchildren[$i]->type == $this->type) {
-                    $obj[] =& $pchildren[$i];
+                if ($pchildren[$i]->name == $this->name) {
+                    if ($byType == true) {
+                        if ($pchildren[$i]->type == $this->type) {
+                            $obj[] =& $pchildren[$i];
+                        }
+                    } else {
+                        $obj[] =& $pchildren[$i];
+                    }
                 }
             }
             for ($i = 0, $count = count($obj); $i < $count; $i++) {
@@ -760,4 +773,4 @@ class Config_Container {
         }
     } // end func writeDatasrc
 } // end class Config_Container
-?>
\ No newline at end of file
+?>
